==> index.php?dir=Deus+Ex%2FLaunchers%2FDeusExe%2Fsrc%2F&file=DeusExe-v5.3-src.zip: DeusExe/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by res.rc
//
#define IDBROWSE                        3
#define IDI_ICON                        101
#define IDD_DIALOG1                     102
#define IDD_DIALOG2                     107
#define IDD_FIXAPP                      107
#define DEFINI                          108
#define DEFUSERINI                      109
#define DXTOOL_ADMIN                    110
#define IDR_INI2                        112
#define IDRUSERINI                      112
#define IDD_DATADIRS                    113
#define CHK_CPUTHREADING                1001
#define IDC_BITMAP1                     1002
#define IDC_PLAY                        1002
#define CHK_CPUTHROTTLING               1002
#define IDC_CONFIG                      1004
#define IDC_EXIT                        1006
#define RADIO_GUIDEFAULT                1006
#define RADIO_GUIFIX                    1007
#define IDC_DATADIRS                    1007
#define IDC_TAB1                        1008
#define TXT_RESX                        1008
#define COMBO_RESOLUTION                1009
#define RADIO_RESCOMMON                 1010
#define IDC_VERSION                     1010
#define RADIO_RESCUSTOM                 1011
#define TXT_GAMEDIR                     1012
#define COMBO_RENDERER                  1013
#define IDC_DDLIST                      1013
#define TXT_RESY                        1014
#define RADIO_16BIT                     1015
#define RADIO_32BIT                     1016
#define CHK_DETAILTEX                   1017
#define TXT_FOV                         1018
#define CHK_DETAILTEX2                  1019
#define CHK_FULLSCREEN                  1019
#define TXT_LATENCY                     1020
#define CHK_DIRECTSOUND                 1021
#define IDC_UP                          1021
#define RADIO_FOVDEFAULT                1022
#define IDC_DOWN                        1022
#define IDC_INIFILES1                   1022
#define RADIO_FOV_5_4                   1023
#define IDC_INIFILES2                   1023
#define RADIO_FOV_16_10                 1024
#define RADIO_FOV_16_9                  1025
#define RADIO_FOV_15_9                  1026
#define RADIO_FOVCUSTOM                 1027
#define CHK_NOMOUSEACCEL                1028
#define IDC_GUI_STATIC                  1029
#define STATIC_GUI                      1029
#define TXT_LATENCY2                    1030
#define TXT_FPSLIMIT                    1030

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        114
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1030
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> index.php?dir=Deus+Ex%2FLaunchers%2FDeusExe%2Fsrc%2F&file=DeusExe-v6.2-src.zip: DeusExe/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by res.rc
//
#define IDBROWSE                        3
#define IDI_ICON                        101
#define IDD_DIALOG1                     102
#define IDD_DIALOG2                     107
#define IDD_FIXAPP                      107
#define DEFINI                          108
#define DEFUSERINI                      109
#define DXTOOL_ADMIN                    110
#define IDR_INI2                        112
#define IDRUSERINI                      112
#define IDD_DATADIRS                    113
#define CHK_CPUTHREADING                1001
#define IDC_BITMAP1                     1002
#define IDC_PLAY                        1002
#define CHK_CPUTHROTTLING               1002
#define IDC_CONFIG                      1004
#define IDC_EXIT                        1006
#define RADIO_GUIDEFAULT                1006
#define RADIO_GUIFIX                    1007
#define IDC_DATADIRS                    1007
#define IDC_TAB1                        1008
#define TXT_RESX                        1008
#define COMBO_RESOLUTION                1009
#define RADIO_RESCOMMON                 1010
#define IDC_VERSION                     1010
#define RADIO_RESCUSTOM                 1011
#define TXT_GAMEDIR                     1012
#define COMBO_RENDERER                  1013
#define IDC_DDLIST                      1013
#define TXT_RESY                        1014
#define RADIO_16BIT                     1015
#define RADIO_32BIT                     1016
#define CHK_DETAILTEX                   1017
#define TXT_FOV                         1018
#define CHK_DETAILTEX2                  1019
#define CHK_FULLSCREEN                  1019
#define TXT_LATENCY                     1020
#define CHK_DIRECTSOUND                 1021
#define IDC_UP                          1021
#define IDC_GUI_STATIC                  1021
#define IDC_DOWN                        1022
#define IDC_INIFILES1                   1022
#define RADIO_FOVDEFAULT                1022
#define RADIO_FOV_5_4                   1023
#define IDC_INIFILES2                   1023
#define RADIO_FOVAUTO                   1023
#define RADIO_FOVCUSTOM                 1024
#define CHK_NOMOUSEACCEL                1028
#define STATIC_GUI                      1029
#define TXT_LATENCY2                    1030
#define TXT_FPSLIMIT                    1030
#define CHK_GUIFIX                      1031
#define IDC_DIRTREE                     1032
#define CHK_GUIFIX2                     1032
#define CHK_USESINGLECPU                1032
#define IDC_WEBSITE                     1035

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        114
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1036
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
